@@ -1,10 +1,13 @@
 #' @importFrom httr GET POST content
 #' @importFrom readr read_tsv cols
-#' @importFrom rjson toJSON
+#' @importFrom jsonlite toJSON
 WebGestaltRNta <- function(organism="hsapiens", network="network_PPI_BIOGRID", method="Network_Retrieval_Prioritization", inputSeed, inputSeedFile, interestGeneType="genesymbol", neighborNum=10, highlightSeedNum=10, sigMethod="fdr", fdrThr=0.05, topThr=10, highlightType="Seeds", outputDirectory=getwd(), projectName=NULL, hostName="http://www.webgestalt.org/") {
 	projectDir <- file.path(outputDirectory, paste0("Project_", projectName))
 	dir.create(projectDir)
 
+	if (length(network) > 1) {
+		stop("NTA does not support multiple databases.")
+	}
 	inputGene <- formatCheck("list", inputGeneFile=inputSeedFile, inputGene=inputSeed)
 	# only networks are in gene symbols
 	# mapping always returns gene symbol, could map to genesymbol but takes two requests
@@ -25,36 +28,21 @@ WebGestaltRNta <- function(organism="hsapiens", network="network_PPI_BIOGRID", m
 	## networks <- unlist(strsplit(network, ",", fixed=TRUE))
 	## May need to bring back analysis of multiple networks
 	fileName <- paste(projectName, network, method, sep=".")
-	randomWalkEnrichment(organism=organism, network=network, method=method, highlightSeedNum=highlightSeedNum, inputSeed=inputGene,
+	goEnrichRes <- randomWalkEnrichment(organism=organism, network=network, method=method, highlightSeedNum=highlightSeedNum, inputSeed=inputGene,
 						sigMethod=sigMethod, fdrThr=fdrThr, topThr=topThr, projectDir=projectDir,
 						topRank=neighborNum, projectName=projectName, hostName=hostName)
-
+	if (is.null(goEnrichRes)) {
+		return(NULL)
+	}
 	enrichResFile <- file.path(projectDir, paste0(fileName, "_enrichedResult.txt"))
 
 	goTermList <- read_tsv(enrichResFile, col_types=cols())$goId
 	inputEndIndex <- length(goTermList)
 
-	queue <- as.list(goTermList)
-	## expand to include all linked nodes
-	edges <- list()
-	while (length(queue) > 0 ) {
-		goTerm <- queue[[1]]
-		if (length(queue) == 1) {
-			queue <- list()
-		} else {
-			queue <- queue[2:length(queue)]
-		}
-		inEdges <- filter(dagInfo, .data$target == goTerm)
-		if (nrow(inEdges) > 0) {
-			edges <- c(edges, lapply(split(inEdges, seq(nrow(inEdges))), function(x) list("data"=x)))
-		}
-		for (parentNode in inEdges$source) {
-			if (!parentNode %in% goTermList) {
-				queue <- c(queue, parentNode)
-				goTermList <- c(goTermList, parentNode)
-			}
-		}
-	}
+	dagTree <- expandDag(goTermList, dagInfo)
+	goTermList <- dagTree$allNodes
+	edges <- dagTree$edges
+	rm(dagTree)
 
 	if (startsWith(hostName, "file://")) {
 		goId2Term <- read_tsv(
@@ -78,7 +66,7 @@ WebGestaltRNta <- function(organism="hsapiens", network="network_PPI_BIOGRID", m
 	}
 	jsonData <- unname(c(jsonData, edges))
 
-	cat(toJSON(jsonData), "\n", sep="", file=jsonFile)
+	cat(toJSON(jsonData, auto_unbox=TRUE), "\n", sep="", file=jsonFile)
 
 	createNtaReport(networkName=network, method=method, sigMethod=sigMethod, fdrThr=fdrThr, topThr=topThr,
 					highlightType=highlightType, outputDirectory=outputDirectory, projectDir=projectDir,
@@ -90,5 +78,5 @@ WebGestaltRNta <- function(organism="hsapiens", network="network_PPI_BIOGRID", m
 	setwd(cwd)
 
 	cat("Results can be found in the ", projectDir, "!\n", sep="")
-
+	return(goEnrichRes)
 }
