@@ -1,10 +1,10 @@
 #' @importFrom readr write_tsv
-#' @importFrom dplyr left_join select arrange %>% desc
-WebGestaltROra <- function(organism="hsapiens", enrichDatabase="geneontology_Biological_Process", enrichDatabaseFile=NULL, enrichDatabaseType=NULL, enrichDatabaseDescriptionFile=NULL,  interestGeneFile=NULL, interestGene=NULL, interestGeneType=NULL, collapseMethod="mean", referenceGeneFile=NULL, referenceGene=NULL, referenceGeneType=NULL, referenceSet=NULL, minNum=10, maxNum=500, fdrMethod="BH", sigMethod="fdr", fdrThr=0.05, topThr=10, reportNum=20, setCoverNum=10, isOutput=TRUE, outputDirectory=getwd(), projectName=NULL, dagColor="binary", nThreads=1, hostName="http://www.webgestalt.org/"){
+#' @importFrom dplyr left_join select arrange %>% desc mutate
+WebGestaltROra <- function(organism="hsapiens", enrichDatabase=NULL, enrichDatabaseFile=NULL, enrichDatabaseType=NULL, enrichDatabaseDescriptionFile=NULL,  interestGeneFile=NULL, interestGene=NULL, interestGeneType=NULL, collapseMethod="mean", referenceGeneFile=NULL, referenceGene=NULL, referenceGeneType=NULL, referenceSet=NULL, minNum=10, maxNum=500, fdrMethod="BH", sigMethod="fdr", fdrThr=0.05, topThr=10, reportNum=20, setCoverNum=10, isOutput=TRUE, outputDirectory=getwd(), projectName=NULL, dagColor="binary", nThreads=1, hostName="http://www.webgestalt.org/") {
 	enrichMethod <- "ORA"
 	projectDir <- file.path(outputDirectory, paste0("Project_", projectName))
 
-	#########Web server will input "NULL" to the R package, thus, we need to change "NULL" to NULL########
+	######### Web server will input "NULL" to the R package, thus, we need to change "NULL" to NULL ########
 	enrichDatabase <- testNull(enrichDatabase)
 	enrichDatabaseFile <- testNull(enrichDatabaseFile)
 	enrichDatabaseType <- testNull(enrichDatabaseType)
@@ -17,112 +17,102 @@ WebGestaltROra <- function(organism="hsapiens", enrichDatabase="geneontology_Bio
 	referenceGeneType <- testNull(referenceGeneType)
 	referenceSet <- testNull(referenceSet)
 
-	################Check parameter################
+	################ Check parameter ################
 	errorTest <- parameterErrorMessage(enrichMethod=enrichMethod, organism=organism, collapseMethod=collapseMethod, minNum=minNum, maxNum=maxNum, fdrMethod=fdrMethod, sigMethod=sigMethod, fdrThr=fdrThr, topThr=topThr, reportNum=reportNum, isOutput=isOutput, outputDirectory=outputDirectory, dagColor=dagColor, hostName=hostName)
 
-	if(!is.null(errorTest)){
-		return(errorTest)
+	if (!is.null(errorTest)) {
+		stop(errorTest)
 	}
 
-	#############Check enriched database#############
-	cat("Uploading the functional categories...\n")
-	enrichD <- loadGeneSet(organism=organism, enrichDatabase=enrichDatabase, enrichDatabaseFile=enrichDatabaseFile, enrichDatabaseType=enrichDatabaseType, enrichDatabaseDescriptionFile=enrichDatabaseDescriptionFile, collapseMethod=collapseMethod, hostName=hostName)
-	if(.hasError(enrichD)){
-		return(enrichD)
-	}
+	############# Check enriched database #############
+	cat("Loading the functional categories...\n")
+	enrichD <- loadGeneSet(organism=organism, enrichDatabase=enrichDatabase, enrichDatabaseFile=enrichDatabaseFile, enrichDatabaseType=enrichDatabaseType, enrichDatabaseDescriptionFile=enrichDatabaseDescriptionFile, hostName=hostName)
 
 	geneSet <- enrichD$geneSet
 	geneSetDes <- enrichD$geneSetDes
 	geneSetDag <- enrichD$geneSetDag
 	geneSetNet <- enrichD$geneSetNet
 	databaseStandardId <- enrichD$standardId
+	rm(enrichD)
 
-	###########Check input interesting gene list###############
-	cat("Uploading the ID list...\n")
+	########### Check input interesting gene list ###############
+	cat("Loading the ID list...\n")
 	interestingGeneMap <- loadInterestGene(organism=organism, dataType="list", inputGeneFile=interestGeneFile, inputGene=interestGene, geneType=interestGeneType, collapseMethod=collapseMethod, hostName=hostName, geneSet=geneSet)
 
-	if(.hasError(interestingGeneMap)){
-		return(interestingGeneMap)
-	}
-
-	if(organism=="others"){
+	if (organism == "others") {
 		interestGeneList <- unique(interestingGeneMap)
-	}else{
+	} else {
 		interestStandardId <- interestingGeneMap$standardId
 		interestGeneList <- unique(interestingGeneMap$mapped[[interestStandardId]])
 	}
 
-	###################load reference gene set for SEA method##############
-	cat("Uploading the reference list...\n")
+	################### Load reference gene set ##############
+	cat("Loading the reference list...\n")
 	referenceGeneList <- loadReferenceGene(organism=organism, referenceGeneFile=referenceGeneFile, referenceGene=referenceGene, referenceGeneType=referenceGeneType, referenceSet=referenceSet, collapseMethod=collapseMethod, hostName=hostName, geneSet=geneSet, interestGeneList=interestGeneList)
 
-	if(.hasError(referenceGeneList)){
-		return(referenceGeneList)
-	}
-
-	##########Create project folder##############
-	if(isOutput==TRUE){
+	########## Create project folder ##############
+	if (isOutput) {
 		dir.create(projectDir)
 
-	######Summarize gene annotation based on the GOSlim###########
-		if(organism!="others"){
-			if(databaseStandardId=="entrezgene"){
-				cat("Summarize the uploaded ID list by GO Slim data...\n")
+	###### Summarize gene annotation based on the GOSlim ###########
+		if (organism != "others") {
+			if (databaseStandardId == "entrezgene") {
+				cat("Summarizing the input ID list by GO Slim data...\n")
 				goSlimOutput <- file.path(projectDir, paste0("goslim_summary_", projectName))
 				re <- goSlimSummary(organism=organism, geneList=interestGeneList, outputFile=goSlimOutput, outputType="png", isOutput=isOutput, hostName=hostName)
-				if(.hasError(re)){
-					return(re)
-				}
 			}
 			write_tsv(interestingGeneMap$mapped, file.path(projectDir, paste0("interestingID_mappingTable_", projectName , ".txt")))
 			write(interestingGeneMap$unmapped, file.path(projectDir, paste0("interestingID_unmappedList_", projectName, ".txt")))
-		}else{
+		} else {
 			write(interestGeneList, file.path(projectDir, paste0("interestList_", projectName, ".txt")))
 		}
 	}
 
-	#############Run enrichment analysis###################
-	cat("Perform the enrichment analysis...\n")
-
-	oraRes <- oraEnrichment(interestGeneList,referenceGeneList,geneSet,minNum=minNum,maxNum=maxNum,fdrMethod=fdrMethod,sigMethod=sigMethod,fdrThr=fdrThr,topThr=topThr)
-
-	if(.hasError(oraRes)){
-		return(oraRes)
+	############# Run enrichment analysis ###################
+	cat("Performing the enrichment analysis...\n")
+	oraRes <- oraEnrichment(interestGeneList, referenceGeneList, geneSet, minNum=minNum, maxNum=maxNum, fdrMethod=fdrMethod, sigMethod=sigMethod, fdrThr=fdrThr, topThr=topThr)
+	if (is.null(oraRes)) {
+		return(NULL)
 	}
-
 	enrichedSig <- oraRes$enriched
 	insig <- oraRes$background
 
 	clusters <- list()
 	geneTables <- list()
 
-	if(!is.null(enrichedSig)){
-		if(!is.null(geneSetDes)){ #######Add extra description information###########
+	if (!is.null(enrichedSig)) {
+		if (!is.null(geneSetDes)) { ####### Add extra description information ###########
 			enrichedSig <- enrichedSig %>%
 				left_join(geneSetDes, by="geneSet") %>%
-				select(.data$geneSet, .data$description, .data$link, .data$C, .data$O, .data$E, .data$R, .data$pValue, .data$FDR, .data$overlapId) %>%
-				arrange(.data$FDR, .data$pValue, desc(.data$C))
+				select(.data$geneSet, .data$description, .data$link, .data$size, .data$overlap, .data$expect, .data$enrichmentRatio, .data$pValue, .data$FDR, .data$overlapId) %>%
+				arrange(.data$FDR, .data$pValue, desc(.data$size)) %>%
+				mutate(description=ifelse(is.na(.data$description), "", .data$description)) # now des could be mixture
 		} else {
 			enrichedSig <- enrichedSig %>%
-				select(.data$geneSet, .data$link, .data$C, .data$O, .data$E, .data$R, .data$pValue, .data$FDR, .data$overlapId) %>%
-				arrange(.data$FDR, .data$pValue, desc(.data$C))
+				select(.data$geneSet, .data$link, .data$size, .data$overlap, .data$expect, .data$enrichmentRatio, .data$pValue, .data$FDR, .data$overlapId) %>%
+				arrange(.data$FDR, .data$pValue, desc(.data$size))
 		}
 
 		geneTables <- getGeneTables(organism, enrichedSig, "overlapId", interestingGeneMap)
 		if (organism != "others") {
-			enrichedSig$link <- mapply(function(link, geneList) linkModification("ORA", enrichDatabase, link, geneList, interestingGeneMap),
+			enrichedSig$link <- mapply(function(link, geneList) linkModification("ORA", link, geneList, interestingGeneMap),
 				enrichedSig$link,
 				enrichedSig$overlapId
 			)
 		}
 
+		if ("database" %in% colnames(geneSet)) {
+			# Add source database for multiple databases
+			enrichedSig <- enrichedSig %>% left_join(unique(geneSet[, c("geneSet", "database")]), by="geneSet")
+		}
+
 		if (organism != "others" && interestGeneType != interestStandardId) {
 			outputEnrichedSig <- mapUserId(enrichedSig, "overlapId", interestingGeneMap)
 		} else {
 			outputEnrichedSig <- enrichedSig
 		}
 
-		if(isOutput==TRUE){
+		if (isOutput) {
 			write_tsv(outputEnrichedSig, file.path(projectDir, paste0("enrichment_results_", projectName, ".txt")))
 			idsInSet <- sapply(enrichedSig$overlapId, strsplit, split=";")
 			names(idsInSet) <- enrichedSig$geneSet
@@ -145,9 +135,8 @@ WebGestaltROra <- function(organism="hsapiens", enrichDatabase="geneontology_Bio
 		}
 	}
 
-	if(isOutput==TRUE){
-
-	##############Create report##################
+	if (isOutput) {
+	############## Create report ##################
 		cat("Generate the final report...\n")
 		createReport(hostName=hostName, outputDirectory=outputDirectory, organism=organism, projectName=projectName, enrichMethod=enrichMethod, geneSet=geneSet, geneSetDes=geneSetDes, geneSetDag=geneSetDag, geneSetNet=geneSetNet, interestingGeneMap=interestingGeneMap, referenceGeneList=referenceGeneList, enrichedSig=enrichedSig, background=insig, geneTables=geneTables, clusters=clusters, enrichDatabase=enrichDatabase, enrichDatabaseFile=enrichDatabaseFile, enrichDatabaseType=enrichDatabaseType, enrichDatabaseDescriptionFile=enrichDatabaseDescriptionFile, interestGeneFile=interestGeneFile, interestGene=interestGene, interestGeneType=interestGeneType, collapseMethod=collapseMethod, referenceGeneFile=referenceGeneFile, referenceGene=referenceGene, referenceGeneType=referenceGeneType, referenceSet=referenceSet, minNum=minNum, maxNum=maxNum, fdrMethod=fdrMethod, sigMethod=sigMethod, fdrThr=fdrThr, topThr=topThr, reportNum=reportNum, dagColor=dagColor)
 
