@@ -11,11 +11,15 @@
 #' @aliases listIDType
 #'
 listIdType <- function(organism="hsapiens",hostName="http://www.webgestalt.org/"){
-	response <- GET(file.path(hostName, "api", "summary", "idtype"))
-	if (response$status_code != 200) {
-		return(webRequestError(response))
+	if (startsWith(hostName, "file://")) {
+		jsonData <- fromJSON(file=removeFileProtocol(file.path(hostName, "idtypesummary.json")))
+	} else {
+		response <- GET(file.path(hostName, "api", "summary", "idtype"))
+		if (response$status_code != 200) {
+			return(webRequestError(response))
+		}
+		jsonData <- content(response)
 	}
-	jsonData <- content(response)
 	idType <- jsonData[[organism]]
 	idType <- sapply(idType,function(e){return(e$name)})
 	return(idType)
