@@ -6,21 +6,33 @@
 #' @keywords internal
 #'
 summaryDescription <- function(projectName, organism, interestGeneFile, interestGene, interestGeneType, enrichMethod, enrichDatabase, enrichDatabaseFile, enrichDatabaseType, enrichDatabaseDescriptionFile, interestingGeneMap, referenceGeneList, referenceGeneFile, referenceGene, referenceGeneType, referenceSet, minNum, maxNum, sigMethod, fdrThr, topThr, fdrMethod, enrichedSig, reportNum, perNum, geneSet, repAdded, hostName) {
-	if(enrichMethod=="ORA"){
+	if (enrichMethod == "ORA") {
 		methodSpecificContent <- specificParameterSummaryOra(organism, referenceGeneList, geneSet, referenceGeneFile, referenceGene, referenceGeneType, referenceSet, minNum, maxNum, sigMethod, fdrThr, topThr, fdrMethod, enrichedSig, reportNum, repAdded, interestingGeneMap)
 	}
 
-	if(enrichMethod=="GSEA"){
+	if (enrichMethod == "GSEA") {
 		methodSpecificContent <- specificParameterSummaryGsea(organism, interestingGeneMap, geneSet, minNum, maxNum, sigMethod, fdrThr, topThr, perNum, enrichedSig, reportNum, repAdded)
 	}
 
 	template <- readLines(system.file("templates/summary.mustache", package="WebGestaltR"))
+	enrichDatabaseInfo <- list()
+	for (enrichDb in enrichDatabase) {
+		if (!is.null(enrichDb)) {
+			enrichDatabaseInfo <- c(enrichDatabaseInfo, list(list(isBuiltIn=TRUE, enrichDatabase=enrichDb)))
+		}
+	}
+	for (i in 1:length(enrichDatabaseFile)) {
+		if (!is.null(enrichDatabaseFile[[i]])) {
+			enrichDatabaseInfo <- c(enrichDatabaseInfo, list(list(isBuiltIn=FALSE, enrichDatabaseFile=enrichDatabaseFile[[i]],
+				hasEnrichDatabaseDescriptionFile=is.null(enrichDatabaseDescriptionFile[[i]]),
+				enrichDatabaseDescriptionFile=enrichDatabaseDescriptionFile[[i]])))
+		}
+	}
 	if (organism != "others") {
 		standardId <- unname(interestingGeneMap$standardId)
 		data <- list(projectName=projectName, enrichMethod=enrichMethod, organism=organism, organismIsOthers=FALSE,
-			enrichDatabase=enrichDatabase, enrichDatabaseIsOthers=enrichDatabase=="others", enrichDatabaseFile=enrichDatabaseFile,
-			enrichDatabaseType=enrichDatabaseType, enrichDatabaseDescriptionFile=enrichDatabaseDescriptionFile,
-			hasEnrichDatabaseDescriptioFile=!is.null(enrichDatabaseDescriptionFile), hasInterestGeneFile=!is.null(interestGeneFile),
+			enrichDatabaseInfo=enrichDatabaseInfo, enrichDatabaseType=enrichDatabaseType,
+			hasInterestGeneFile=!is.null(interestGeneFile),
 			interestGeneFileBase=ifelse(is.null(interestGeneFile), "", basename(interestGeneFile)), interestGeneType=interestGeneType,
 			numUserId=nrow(interestingGeneMap$mapped)+length(interestingGeneMap$unmapped),
 			numMappedUserId=nrow(interestingGeneMap$mapped), numUniqueMappedId=length(unique(interestingGeneMap$mapped[[standardId]])),
@@ -29,9 +41,8 @@ summaryDescription <- function(projectName, organism, interestGeneFile, interest
 		)
 	}else {
 		data <- list(projectName=projectName, enrichMethod=enrichMethod, organism=organism, organismIsOthers=TRUE,
-			enrichDatabase=enrichDatabase, enrichDatabaseIsOthers=enrichDatabase=="others", enrichDatabaseFile=enrichDatabaseFile,
-			enrichDatabaseType=enrichDatabaseType, enrichDatabaseDescriptionFile=enrichDatabaseDescriptionFile,
-			hasEnrichDatabaseDescriptioFile=!is.null(enrichDatabaseDescriptionFile), hasInterestGeneFile=!is.null(interestGeneFile),
+			enrichDatabaseInfo=enrichDatabaseInfo, enrichDatabaseType=enrichDatabaseType,
+			hasInterestGeneFile=!is.null(interestGeneFile),
 			interestGeneFileBase=ifelse(is.null(interestGeneFile), "", basename(interestGeneFile)), interestGeneType=interestGeneType,
 			idIsEntrezGene=FALSE, methodSpecificContent=methodSpecificContent
 		)
@@ -51,21 +62,20 @@ summaryDescription <- function(projectName, organism, interestGeneFile, interest
 #'
 specificParameterSummaryOra <- function(organism, referenceGeneList, geneSet, referenceGeneFile, referenceGene, referenceGeneType, referenceSet, minNum, maxNum, sigMethod, fdrThr, topThr, fdrMethod, enrichedSig, reportNum, repAdded, interestingGeneMap) {
 	organismIsOthers <- organism == "others"
-	if(!organismIsOthers){
+	if (!organismIsOthers) {
 		standardId <- interestingGeneMap$standardId
 		interestGeneList <- unique(interestingGeneMap$mapped[[standardId]])
 		numAnnoRefUserId <- length(intersect(interestGeneList, intersect(referenceGeneList, geneSet$gene)))
-	}else{  ###for others
+	} else {  ### for others
 		standardId <- NULL
 		interestGeneList <- unique(interestingGeneMap)
 		numAnnoRefUserId <- NULL
-
 	}
 	numAnnoRefId <- length(intersect(referenceGeneList, geneSet$gene))
 	hasEnrichedSig <- !is.null(enrichedSig)
 	if (hasEnrichedSig) {
 		numEnrichedSig <- nrow(enrichedSig)
-		showAll <- reportNum>=numEnrichedSig
+		showAll <- reportNum >= numEnrichedSig
 	} else {
 		numEnrichedSig <- NULL
 		showAll <- NULL
@@ -92,7 +102,7 @@ specificParameterSummaryOra <- function(organism, referenceGeneList, geneSet, re
 #'
 specificParameterSummaryGsea <- function(organism, interestingGeneMap, geneSet, minNum, maxNum, sigMethod, fdrThr, topThr, perNum, enrichedSig, reportNum, repAdded) {
 	organismIsOthers <- organism == "others"
-	if(!organismIsOthers){
+	if (!organismIsOthers) {
 		standardId <- interestingGeneMap$standardId
 		interestGeneList <- unique(interestingGeneMap$mapped[[standardId]])
 		numUniqueUserId <- length(interestGeneList)
@@ -111,10 +121,10 @@ specificParameterSummaryGsea <- function(organism, interestingGeneMap, geneSet,
 		)
 
 	if(hasEnrichedSig){
-		data$numPosRel <- nrow(filter(enrichedSig, .data$NES>0))
-		data$numNegRel <- nrow(filter(enrichedSig, .data$NES<0))
-		data$isPosRel <- data$numPosRel>0
-		data$isNegRel <- data$numNegRel>0
+		data$numPosRel <- nrow(filter(enrichedSig, .data$normalizedEnrichmentScore > 0))
+		data$numNegRel <- nrow(filter(enrichedSig, .data$normalizedEnrichmentScore < 0))
+		data$isPosRel <- data$numPosRel > 0
+		data$isNegRel <- data$numNegRel > 0
 		data$showAll <- reportNum >= nrow(enrichedSig)
 	}
 
